mix ex_icon.gen.icons (ExIcon v0.3.0)

Copy Markdown View Source

Downloads and generates all icons.

The task expects the configuration file .ex_icon.exs to exist.

Usage

Download and generate icons for all configured providers:

mix ex_icon.gen.icons

Download and generate icons for a single named provider:

mix ex_icon.gen.icons --icon-set lucide

The value must reference one of the top level keys in your configuration file.