Downloads and generates all icons.
The task expects the configuration file .ex_icon.exs to exist.
Usage
Download and generate icons for all configured providers:
mix ex_icon.gen.iconsDownload and generate icons for a single named provider:
mix ex_icon.gen.icons --icon-set lucideThe value must reference one of the top level keys in your configuration file.